//*****************************************************************************
// CAPT_Sandbox.h
//
//! This is the CapTIvate software library sandbox.  This can be used
//! to have version control in GIT of functions that are in development/test,
//! but not released to the full CapTIvate library yet.
//
//*****************************************************************************

#ifndef __CAPT_SANDBOX__
#define __CAPT_SANDBOX__

#include "CAPT_Type.h"
#include "CAPT_HAL.h"
#include "CAPT_Touch.h"
#include "CAPT_Calibration.h"

#define DEFAULT_CALIBRATION     0
#define REFCAP_CALIBRATION      1
// USER DEFINES THE FOLLOWING:
#define CALIBRATION_METHOD      (REFCAP_CALIBRATION)
#define REFCAP_VALUE            CAPT_REFERENCE_CAP__SELF_1P5PF
#define TARGET_DELTA            150
//*****************************************************************************
//
//! Calibrate the passed sensor based on a target delta (measurement deviation)
//! when an internal reference capacitance is applied to each element.
//! This is in contrast to the standard CAPT_calibrateSensor() routine, which
//! calibrates each channel to a specific conversion count in the idle state.
//! The main difference is that this fuction calibrates for normalized deltas
//! between sensors, whereas CAPT_calibrateSensor() calibrates for normalized
//! idle values (LTA's).
//!
//! NOTE: This function forces the sensor recalibration enable to false,
//! as the existing re-calibration functionality is not compatible with this
//! style calibration.
//!
//! \param pSensor is a pointer to the sensor to calibrate
//! \param ui16TargetDelta is the target delta for each element due to the
//!        application of the reference capacitance
//! \param ui8RefCap is the reference capacitance to apply and calibrate to.
//!
//! \par Returns
//!		none
//
//*****************************************************************************
void CAPT_calibrateSensorToReference(tSensor *pSensor, 
    uint16_t ui16TargetDelta, uint8_t ui8RefCap);
	
//*****************************************************************************
//
//! The calibrate offset parameter function identifies the correct offset tap
//! to achieve the specified measurement delta when the requested calibration
//! capacitor is applied.
//!
//! \param pSensor is a pointer to the sensor to calibrate
//! \param pbEndOfConversionFlag is a pointer to the end of conversion
//!        flag to tell the algorithm when a conversion is complete
//! \param ui8Freq is the oscillator setting to run this conversion at.
//!        Valid options are 0-3.
//! \param ui16TargetDelta is the measurement delta due to the reference cap
//!        to calibrate to
//! \param ui8RefCap is the reference capacitor to calibrate to.
//!        Valid options include:
//!        
//
//! \par Returns
//!		none
//
//*****************************************************************************
void CAPT_calibrateOffsetToReference(tSensor *pSensor,
    volatile bool *pbEndOfConversionFlag, uint8_t ui8Freq,
    uint16_t ui16TargetDelta, uint8_t ui8RefCap);
	
#endif // __CAPT_SANDBOX__
